@@ -11,14 +11,16 @@ from .annotations.ticklabel import _tpl_ticklabel
 from .cycle_list import _tpl_cycle_list
 from .limits import _tpl_limits
 from .attribute import _tpl_attribute_variable
+from .annotations.annotation import _tpl_annotation
 
 
 class figure:
   PDF_COMPILE_CMD = "pdflatex -halt-on-error -interaction nonstopmode TEXFILE | grep '^!.*' -A200 --color=always"
 
-  def __init__(self, figsize: tuple = None):
+  def __init__(self, figsize: tuple = None, name: str = None):
     if figsize is None:
       figsize = (8, 5)
+    self.__name: str = name if name is not None else 'tplaxis'
     self.__figsize: tuple = figsize
     self.__curves: list[_tpl_curve] = []
     self.__xlabel: _tpl_label = _tpl_label(token="xlabel")
@@ -32,6 +34,7 @@ class figure:
     self.__cycle_list: _tpl_cycle_list = _tpl_cycle_list("multi")
     self.__limits: _tpl_limits = _tpl_limits()
     self.__title: _tpl_attribute_variable = _tpl_attribute_variable(token="title")
+    self.__annotations: _tpl_annotation = []
 
   def plot(self, x: Iterable, y: Iterable, xerror: Iterable = None, yerror: Iterable = None,
            *args, **kwargs):
@@ -162,6 +165,9 @@ class figure:
   def repeat_style(self, ntimes: int = None):
     self.__cycle_list.repeat_style(ntimes)
 
+  def add_annotation(self, pos: str, label: str, xshift: str = None, yshift: str = None):
+    self.__annotations.append(_tpl_annotation(pos, label, self.__name, xshift, yshift))
+
   def __create_tex(self):
     preable_cmd = """\\documentclass[tikz]{standalone}\n
 \\usepackage{pgfplots}
@@ -178,6 +184,7 @@ class figure:
     begintikz_cmd = "\\begin{tikzpicture}\n" if include_begintikz else ""
 
     body_cmd = f"""\\begin{{axis}}[
+  name={self.__name},
   label style={{
     font=\\large
   }},
@@ -205,10 +212,13 @@ class figure:
 
     post_cmd = "\n\\end{axis}\n"
 
+    annotations = "".join(str(a) + "\n" for a in self.__annotations)
+
     endtikz_cmd = "\\end{tikzpicture}\n" if include_begintikz else ""
 
     return begintikz_cmd \
       + body_cmd \
       + "\n".join([_compactify(pc) for pc in plot_cmd]) \
       + post_cmd \
+      + annotations \
       + endtikz_cmd
